@@ -9,15 +9,16 @@ class TextField : public QTextEdit
     Q_OBJECT
 public:
     explicit TextField(QWidget *parent = 0);
+    //void setReadOnly(bool ro);
+    //void setEnabled(bool);
 
 signals:
 
 public slots:
 
 protected:
-    void mouseReleaseEvent(QMouseEvent *e);
-//    void on_cursor();
-//    void setActiveLine( int line );
+    //void mouseReleaseEvent(QMouseEvent *e);
+    bool eventFilter(QObject *, QEvent *);
 
 };
 
