@@ -409,7 +409,7 @@ void TextProcessor::addText(QString sWord)
 {
     disconnect(m_smsEdit,SIGNAL(selectionChanged()),0,0);
 
-    qDebug()<<m_cursorSmsText.position();
+    //qDebug()<<m_cursorSmsText.position();
     m_cursorSmsText.clearSelection();
     m_cursorSmsText.insertText(capitalizeIfNeeded(sWord));
 
@@ -424,7 +424,7 @@ void TextProcessor::updateText(QString sWord)
     m_cursorSmsText.insertText(capitalizeIfNeeded(sWord));
     connect(m_smsEdit,SIGNAL(selectionChanged()),this,SLOT(cursorPosChanged()));
 
-    qDebug() << "Write sms:" << m_smsEdit->toPlainText();
+    //qDebug() << "Write sms:" << m_smsEdit->toPlainText();
 }
 
 QString TextProcessor::capitalizeIfNeeded(QString sWord)
@@ -692,7 +692,7 @@ void TextProcessor::cursorPosChanged()
     {
         m_smsEdit->disconnect();
 
-        qDebug() << "cursor moved";
+        //qDebug() << "cursor moved";
         m_cursorSmsText = m_smsEdit->textCursor(); // retrieve the visible cursor
         m_cursorSmsText.select(QTextCursor::WordUnderCursor);
         m_nBeginWord = m_cursorSmsText.anchor();
@@ -701,7 +701,7 @@ void TextProcessor::cursorPosChanged()
 
         if(m_cursorSmsText.hasSelection())
         {
-            qDebug() << "Selected text from Cursor moved" << m_cursorSmsText.selectedText().toAscii();
+            //qDebug() << "Selected text from Cursor moved" << m_cursorSmsText.selectedText().toAscii();
 
             QString *sWord = new QString(m_cursorSmsText.selectedText());
             m_sCompleteValue = *m_dict->calculateKey(sWord);
@@ -716,7 +716,7 @@ void TextProcessor::cursorPosChanged()
         }
         else
         {
-            qDebug() << "Nothing selected";
+            //qDebug() << "Nothing selected";
             m_sCompleteValue.clear();
             m_nWordIndex = 0;
             m_lWord.clear();
@@ -752,12 +752,23 @@ void TextProcessor::alarmNewChar()
 /** Set text in textEdit **/
 void TextProcessor::setText(QString sWord)
 {
+    //Reset FW state
+    m_nState = STATE_SEND;
+    m_sCompleteValue.clear();
+    m_lWord.clear();
+    m_nWordIndex=0;
+
+    //update char and sms count
+    updateCharCounter(ACTION_SEND);
+
     if(!m_bQwertyEnable)
         m_smsEdit->disconnect();
 
+    m_smsEdit->setEnabled(true);
     m_cursorSmsText.select(QTextCursor::Document);
     m_cursorSmsText.removeSelectedText();
     m_cursorSmsText.insertText(sWord);
+    m_smsEdit->ensureCursorVisible();
 
     if(!m_bQwertyEnable)
     {
@@ -782,10 +793,11 @@ QPushButton* TextProcessor::getSendBt()
 /** Commit text to external app**/
 void TextProcessor::commit()
 {
-    parentWidget()->parentWidget()->hide();
+    m_smsEdit->setEnabled(false);
+    //parentWidget()->parentWidget()->hide();
 
     //wait a moment before commit, so client re-gain focus
-    sleep(0.1);
+    //sleep(0.8);
 
     QDBusMessage msg = QDBusMessage::createMethodCall(
             "it.rsc.fastsms.plugin.connection", // --dest
@@ -802,15 +814,21 @@ void TextProcessor::commit()
     //qDebug() << msg;
     bool ok = msg.type() != QDBusMessage::ErrorMessage;
 
-    qDebug() << "Sended:" << msg;
-    qDebug() << "Sending state:" << ok;
+    //qDebug() << "Sended:" << msg;
+    qDebug() << "Sended:" << ok;
 
+    //Wait for text commit(?)
+    //sleep(2);
+
+    //Reset field
+    setText("");
+/*
     //Reset fastwrite state
     if(!m_bQwertyEnable)
         m_smsEdit->disconnect();
 
     m_nState = STATE_SEND;
-    m_smsEdit->clear();
+    //m_smsEdit->clear();
     m_sCompleteValue.clear();
     //m_phoneNumber->clear();
     m_lWord.clear();
@@ -818,7 +836,7 @@ void TextProcessor::commit()
 
     //update char and sms count
     updateCharCounter(ACTION_SEND);
-    //
+
 
     if(!m_bQwertyEnable)
     {
@@ -826,6 +844,38 @@ void TextProcessor::commit()
         connect(m_smsEdit,SIGNAL(selectionChanged()),this,SLOT(cursorPosChanged()));
         //Reset FastWrite status
         processAlfanumeric(Keyboard::DELETE);
-    }
+    }*/
 }
 
+//QString TextProcessor::requestCommit()
+//{
+//    QString msg = m_smsEdit->toPlainText();
+//    qDebug() << "msg_1:" << msg;
+
+//    //Reset fastwrite state
+//    if(!m_bQwertyEnable)
+//        m_smsEdit->disconnect();
+
+//    m_nState = STATE_SEND;
+//    m_smsEdit->clear();
+//    m_sCompleteValue.clear();
+//    //m_phoneNumber->clear();
+//    m_lWord.clear();
+//    m_nWordIndex=0;
+
+//    //update char and sms count
+//    updateCharCounter(ACTION_SEND);
+//    //
+
+//    if(!m_bQwertyEnable)
+//    {
+//        connect(m_smsEdit,SIGNAL(textChanged()),this,SLOT(smsChanged()));
+//        connect(m_smsEdit,SIGNAL(selectionChanged()),this,SLOT(cursorPosChanged()));
+//        //Reset FastWrite status
+//        processAlfanumeric(Keyboard::DELETE);
+//    }
+
+//    qDebug() << "msg_2:" << msg;
+//    return msg;
+//}
+
